<?php

if (!include_once './lib/libTest.php') {
	/* Try and provide enough information to debug the missing file. */
	echo '<br /><span class="notsupported">Unable to find phpUserTrack/lib/libTest.php. ' .
	'Your phpUserTrack installation may be missing critical files, or PHP may not ' .
	'have sufficient permissions to include files. There may be error messages printed ' .
	'above this message that will help you in debugging the problem.</span>';
	exit;
}

$phpUserTrack_test = & new phpUserTrack_Test();

/* phpUserTrack definitions. */
$module = 'phpUserTrack';
require_once './include/version.php';
$module_version = PHPUSERTRACK_VERSION;

$templates_c_perm = substr(sprintf('%o', fileperms('templates_c')), -4);
$browscap_perm = substr(sprintf('%o', fileperms('include/browscap.ini')), -4);
$confExist = file_exists('conf/conf.php');

$module_list = array (
	'mysqli' => array (
		'descrip' => 'MySQLi Support',
		'fatal' => true,
		'error' => 'phpUserTrack cannot run without MySQLi support in PHP'
	),
	'gd' => array (
		'descrip' => _('GD Graphics Library'),
		'fatal' => true,
		'error' => 'Provides dynamic graph images'
	),
);

$pear_list = array(     
	'Net_GeoIP' => array(         
		'path' => 'Net/GeoIP.php',         
		'error' => 'You do not have the GeoIP package installed on your system. ' .
					'Lots of cool functionality comes from installing it, so you should :P',
		'required' => false    
		),
	'MDB2' => array(         
		'path' => 'MDB2.php',         
		'error' => 'Database abstraction layer.',
		'required' => true    
		),
	'MDB2 MySQL Driver' => array(         
		'path' => 'MDB2/Driver/mysql.php',         
		'error' => 'MySQL Database abstraction layer.',
		'required' => false    
		),
	'MDB2 MySQLi Driver' => array(         
		'path' => 'MDB2/Driver/mysqli.php',         
		'error' => 'MySQLi Database abstraction layer.',
		'required' => true    
		),
	); 
	
$module_output = $phpUserTrack_test->phpModuleCheck($module_list);
$pear_output = $phpUserTrack_test->PEARModuleCheck($pear_list);

function success_fail($test, $want, $msg = null) {
	if ($test == $want) {
		echo '<img src="images/success.png" /><br />';
	} else {
		echo '<img src="images/error.png" />&nbsp;&nbsp;';
		exit('<strong>' . $msg . '</strong><br />');
	}
	
}

?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.1//EN" "http://www.w3.org/TR/xhtml11/DTD/xhtml11.dtd">


<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en">
  <head>
  <meta http-equiv="Content-Type" content="text/html; charset=UTF-8" />
  <title>phpUserTrack Admin Page</title>
  <script type="text/javascript" src="javascript/nicetitle.js"></script>
  <link href="style.css" rel="stylesheet" type="text/css" />

  </head>
  <body>
  
  <h1 style="margin: 0px;"><img src="images/logo.png" /></h1>
  
    
  <div id="container">
  
    <h2>Installation</h2>
    
    <h3>File Permissions</h3>
    <em>templates_c</em> Directory Permission: 
    <?php 
    	success_fail($templates_c_perm, '0777', 'Please run <code>chmod 777 templates_c</code> in the root 
phpUserTrack directory');
    ?>
    <em>browscap.ini</em> File Permission: 
    <?php 
<<<<<<< .mine
    	success_fail($browscap_perm, '0777', 'Please run <code>chmod 755 include/browscap.ini</code> in the root phpUserTrack directory');
=======
    	echo success_fail($browscap_perm, '0777', 'Please run <code>chmod 777 include/browscap.ini</code> in the root phpUserTrack directory');
>>>>>>> .r1073
    ?>
    
    <h3>Configuration</h3>
    <em>conf.php</em> Configuration File Exists: 
    <?php 
    	success_fail($confExist, true, 'Please copy conf/conf.php.dist to conf/conf.php and edit the file to match your configuration');
    ?>
    
    <h3>PHP Module Capabilities</h3>
<ul>
    <?php echo $module_output ?>
</ul>

<h3>PEAR</h3>
<ul>
	<?php echo $pear_output ?>
</ul>

<h3>Database Initialization</h3>
Database Connection:
<?php 
	include_once dirname(__FILE__) . '/conf/conf.php';
	global $conf;
	$mysqli = @new mysqli($conf['mysqlHost'], $conf['mysqlUsername'], $conf['mysqlPassword'], $conf['mysqlDbName']);
	success_fail(mysqli_connect_errno(), null, 'Could not establish a connection to your MySQL Server. Check your host configuration in <code>conf/conf.php</code>');
	echo $mysqli->stat();
?>

</div>

</body>
</html>
