<?php
/**
 * Plugin class library
 * @author Christopher Troup <mini@chatetheory.com>
 * @package phpUserTrack
 * @subpackage Plugins
 */

require_once dirname(__FILE__) . '/libdb.php';
require_once dirname(__FILE__) . '/plugin.php';
require_once dirname(__FILE__) . '/libPrefs.php';

class plugins {
	/**
	 * Registered hooks array
	 * @var array
	 */
	var $hooks = array( 'ip.pre' => array(), 
			'ip.post' => array(),
			'data.pre' => array(), 
			'data.post' => array(),
			'graph.prerender' => array(),
			'graph.postrender' => array());
	var $db;
	
	/**
	 * Register a new plugin and make availible to the proper hook
	 * @global array $conf
	 */
	function plugins() {
		global $conf;
		$prefs = new Prefs(md5(__CLASS__));
		$active = $prefs->getValues();

		if (isset($active)) {
			foreach ($active as $classname) {
				$this->addPlugin($classname);
			}	
		}
	}
	
	function addPlugin($classname) {
		//echo array_search($classname, $this->getActiveNames());
		foreach ($this->getActiveNames() as $name) {
			if ($classname == $name) {
				return false;
			}
		}
		require_once dirname(__FILE__) . '/../plugins/phpusertrack.plugin.' . $classname . '.php';
		if (!class_exists($classname)) {
			/** @todo class doesent exist */
		}
		@$obj = &new $classname($classname);
		$obj->_active = true;
	
		$prefs = new Prefs(md5($classname));
		$obj->data = $prefs->getValues();
	
		array_push($this->hooks[$obj->_type()], &$obj);
		return true;
	}
	
	function removePlugin($classname) {
		
		foreach ($this->hooks as $i => $hookType) {
			foreach ($hookType as $j => $hook) {
				if ($hook->_name == $classname) {
					$hookid = key($hookType);
					$hookmethod = key($this->hooks);
					unset($this->hooks[$i][$j]);
					return true;
				}
			}
		}
		return false;
	}
	
	function getName($namespace) {
		$plugin = $this->getPlugin($namespace);
		return $plugin->_name;
	}
	
	function &getPlugin($namespace) {
		$all = $this->getAll();
		foreach ($all as $plugin) {
			if ($plugin->_namespace == $namespace) {
				return $plugin;
			}
		}
	}
	
	function &getActive() {
		$active = array();
		foreach($this->hooks as $plugintype) {
			foreach ($plugintype as $plugin) {
				$active[] = $plugin->_namespace;
			}
		}
		return $active;
	}
	
	function getActiveNames() {
		$active = array();
		foreach($this->hooks as $plugintype) {
			foreach ($plugintype as $plugin) {
				$active[] = $plugin->_name;
			}
		}
		return $active;
	}
	
	function getAll() {
		$all = array();
		$active = $this->getActive();
		foreach (glob(dirname(__FILE__) . '/../plugins/phpusertrack.plugin.*.php') as $filename) {
	    	require_once $filename;
	    	
	    	$basename = basename($filename);
	    	$pieces = explode(".", $basename);
			$classname =  $pieces[2];
			@$obj = &new $classname($classname);
			if((array_search($obj->_namespace, $active) > 0) || (array_search($obj->_namespace, $active) === 0)) {
				$obj->_active = true;
			} else {
				$obj->_active = false;
			}
			$all[] = $obj;
		}
		rsort($all);
		return $all;
	}
}

?>
