<?php

//error_reporting(0);

/* Register a session. */
session_start();
ini_set('register_long_arrays','1');

$passTests = true;

/* Initialize the phpUserTrack_Test:: class. */
if (!include_once './lib/libTest.php') {
	/* Try and provide enough information to debug the missing file. */
	echo '<br /><span class="notsupported">Unable to find phpUserTrack/lib/libTest.php. ' .
	'Your phpUserTrack installation may be missing critical files, or PHP may not ' .
	'have sufficient permissions to include files. There may be error messages printed ' .
	'above this message that will help you in debugging the problem.</span>';
	exit;
}

/* If we've gotten this far, we should have found enough of phpUserTrack to run
 * tests. Create the testing object. */
$phpUserTrack_test = & new phpUserTrack_Test();

/* phpUserTrack definitions. */
$module = 'phpUserTrack';
require_once './include/version.php';
$module_version = PHPUSERTRACK_VERSION;

/* PHP module capabilities. */
$module_list = array (
	'mysqli' => array (
		'descrip' => 'MySQLi Support',
		'fatal' => true,
		'error' => 'phpUserTrack cannot run without MySQLi support in PHP'
	),
	'gd' => array (
		'descrip' => _('GD Graphics Library'),
		'fatal' => true,
		'error' => 'Provides dynamic graph images'
	),
	'tidy' => array (
		'descrip' => 'HTML Tidy Support',
		'fatal' => false,
		'error' => 'Provides HTML cleanup'
	)
);

$pear_list = array(     
	'Net_GeoIP' => array(         
		'path' => 'Net/GeoIP.php',         
		'error' => 'You do not have the GeoIP package installed on your system. ' .
					'Lots of cool functionality comes from installing it, so you should :P',
		'required' => false    
		),
	'MDB2' => array(         
		'path' => 'MDB2.php',         
		'error' => 'Database abstraction layer.',
		'required' => true    
		),
	'MDB2 MySQL Driver' => array(         
		'path' => 'MDB2/Driver/mysql.php',         
		'error' => 'MySQL Database abstraction layer.',
		'required' => false    
		),
	'MDB2 MySQLi Driver' => array(         
		'path' => 'MDB2/Driver/mysqli.php',         
		'error' => 'MySQLi Database abstraction layer.',
		'required' => true    
		),
	'Structures Graph' => array(
		'path' => 'Structures/Graph.php',
		'error' => 'Directed Graph Package',
		'required' => true
		),
	'Cache Lite' => array(         
		'path' => 'Cache/Lite.php',         
		'error' => 'Caching framework. Speeds up page display.',
		'required' => false    
		)
	); 

/* Required configuration files. */
$file_list = array (
	'conf/conf.php' => null
);

$module_output = $phpUserTrack_test->phpModuleCheck($module_list);
$config_output = $phpUserTrack_test->requiredFileCheck($file_list);
$pear_output = $phpUserTrack_test->PEARModuleCheck($pear_list);
?>

<html>
<head>
<title>phpUserTrack System Capabilities Test</title>
<link href="style.css" rel="stylesheet" type="text/css" />
</head>
<body>
<h1>phpUserTrack System Capabilities Test (version <?php echo PHPUSERTRACK_VERSION; ?>)</h1>
<div id="container">
<?php


/* Display PHP Version information. */
$php_info = $phpUserTrack_test->getPhpVersionInformation();
?>
<h2>PHP Version</h2>
<ul>
    <li>PHP Version: <?php echo $php_info->version ?></li>
    <li>PHP Major Version: <?php echo $php_info->major ?></li>
<?php if (isset($php_info->minor)): ?>
    <li>PHP Minor Version: <?php echo $php_info->minor ?></li>
<?php endif; ?>
<?php if (isset($php_info->subminor)): ?>
    <li>PHP Subminor Version: <?php echo $php_info->subminor ?></li>
<?php endif; ?>
    <li>PHP Version Classification: <?php echo $php_info->class ?></li>
    <li style="color:<?php echo $php_info->status_color ?>"><strong><?php echo $php_info->status ?></strong></li>
<?php if (isset($php_info->version_check)): ?>
    <li><?php echo $php_info->version_check ?></li>
<?php endif; ?>
<?php if (isset($php_info->insecure)): ?>
    <li style="color:orange"><strong><?php echo $php_info->insecure ?><strong></li>
<?php endif; ?>
</ul>

<h2>PHP Module Capabilities</h2>
<ul>
    <?php echo $module_output ?>
</ul>

<h2>PEAR</h2>
<ul>
	<?php echo $pear_output ?>
</ul>

<h2>Required phpUserTrack Configuration Files</h2>
<ul>
    <?php echo $config_output ?>
</ul>

<?php

if ($passTests) {
	echo '<h2 class="supported">phpUserTrack Passes all tests</h2>';
} else {
	echo '<h2 class="notsupported">phpUserTrack Failed tests</h2>';
}

echo '<a href="javascript/javatest.html">Test Javascript Submit</a>';

phpinfo();
?>

</div>
</body>
</html>
